@@ -95,6 +95,14 @@ void Fl_set_visible_focus(int);
 
 void Fl_set_box_type(int, int);
 
+int Fl_box_shadow_width(void);
+
+void Fl_set_box_shadow_width(int W);
+
+int Fl_box_border_radius_max(void);
+
+void Fl_set_box_border_radius_max(int R);
+
 unsigned int Fl_get_rgb_color(unsigned char r, unsigned char g, unsigned char b);
 
 void Fl_set_color(unsigned int c, unsigned char r, unsigned char g, unsigned char b);
@@ -251,6 +259,12 @@ int Fl_clipboard_contains(const char *type);
 
 void Fl_event_dispatch(int (*cb)(int event, void *));
 
+unsigned int Fl_inactive(unsigned int c);
+
+unsigned int Fl_lighter(unsigned int c);
+
+unsigned int Fl_darker(unsigned int c);
+
 #ifdef __cplusplus
 }
 #endif
