@@ -23,37 +23,37 @@
 
 #define VALUATOR_DEFINE(widget)                                                                    \
     void widget##_set_bounds(widget *self, double a, double b) {                                   \
-        LOCK(self->bounds(a, b);)                                                                  \
+        LOCK(self->bounds(a, b));                                                                  \
     }                                                                                              \
     double widget##_minimum(widget *self) {                                                        \
-        LOCK(auto ret = self->minimum(););                                                         \
+        LOCK(auto ret = self->minimum());;                                                         \
         return ret;                                                                                \
     }                                                                                              \
     void widget##_set_minimum(widget *self, double a) {                                            \
-        LOCK(self->minimum(a);)                                                                    \
+        LOCK(self->minimum(a));                                                                    \
     }                                                                                              \
     double widget##_maximum(widget *self) {                                                        \
-        LOCK(auto ret = self->maximum(););                                                         \
+        LOCK(auto ret = self->maximum());;                                                         \
         return ret;                                                                                \
     }                                                                                              \
     void widget##_set_maximum(widget *self, double a) {                                            \
-        LOCK(self->maximum(a);)                                                                    \
+        LOCK(self->maximum(a));                                                                    \
     }                                                                                              \
     void widget##_set_range(widget *self, double a, double b) {                                    \
-        LOCK(self->range(a, b);)                                                                   \
+        LOCK(self->range(a, b));                                                                   \
     }                                                                                              \
     void widget##_set_step(widget *self, double a, int b) {                                        \
-        LOCK(self->step(a, b);)                                                                    \
+        LOCK(self->step(a, b));                                                                    \
     }                                                                                              \
     double widget##_step(widget *self) {                                                           \
-        LOCK(auto ret = self->step(););                                                            \
+        LOCK(auto ret = self->step());;                                                            \
         return ret;                                                                                \
     }                                                                                              \
     void widget##_set_precision(widget *self, int digits) {                                        \
-        LOCK(self->precision(digits);)                                                             \
+        LOCK(self->precision(digits));                                                             \
     }                                                                                              \
     double widget##_value(widget *self) {                                                          \
-        LOCK(auto ret = self->value(););                                                           \
+        LOCK(auto ret = self->value());;                                                           \
         return ret;                                                                                \
     }                                                                                              \
     int widget##_set_value(widget *self, double val) {                                             \
@@ -82,11 +82,12 @@ WIDGET_CLASS(Fl_Slider)
 WIDGET_DEFINE(Fl_Slider)
 
 float Fl_Slider_slider_size(const Fl_Slider *self) {
-    LOCK(auto ret = self->slider_size()); return ret;
+    LOCK(auto ret = self->slider_size());
+    return ret;
 }
 
 void Fl_Slider_set_slider_size(Fl_Slider *self, float v) {
-    LOCK(self->slider_size((double)v);)
+    LOCK(self->slider_size((double)v));
 }
 
 int Fl_Slider_slider_box(const Fl_Slider *self) {
@@ -95,7 +96,7 @@ int Fl_Slider_slider_box(const Fl_Slider *self) {
 }
 
 void Fl_Slider_set_slider_box(Fl_Slider *self, int c) {
-    LOCK(self->slider((Fl_Boxtype)c);)
+    LOCK(self->slider((Fl_Boxtype)c));
 }
 
 VALUATOR_DEFINE(Fl_Slider)
@@ -117,19 +118,21 @@ WIDGET_CLASS(Fl_Dial)
 WIDGET_DEFINE(Fl_Dial)
 
 short Fl_Dial_angle1(const Fl_Dial *self) {
-    LOCK(auto ret = self->angle1()); return ret;
+    LOCK(auto ret = self->angle1());
+    return ret;
 }
 
 short Fl_Dial_angle2(const Fl_Dial *self) {
-    LOCK(auto ret = self->angle2()); return ret;
+    LOCK(auto ret = self->angle2());
+    return ret;
 }
 
 void Fl_Dial_set_angle1(Fl_Dial *self, short val) {
-    LOCK(self->angle1(val);)
+    LOCK(self->angle1(val));
 }
 
 void Fl_Dial_set_angle2(Fl_Dial *self, short val) {
-    LOCK(self->angle2(val);)
+    LOCK(self->angle2(val));
 }
 
 VALUATOR_DEFINE(Fl_Dial)
@@ -161,7 +164,8 @@ void Fl_Value_Slider_set_text_color(Fl_Value_Slider *self, unsigned int c) {
 }
 
 unsigned int Fl_Value_Slider_text_color(Fl_Value_Slider *self) {
-    LOCK(auto ret = self->textcolor()); return ret;
+    LOCK(auto ret = self->textcolor());
+    return ret;
 }
 
 void Fl_Value_Slider_set_text_font(Fl_Value_Slider *self, int f) {
@@ -169,7 +173,8 @@ void Fl_Value_Slider_set_text_font(Fl_Value_Slider *self, int f) {
 }
 
 int Fl_Value_Slider_text_font(Fl_Value_Slider *self) {
-    LOCK(auto ret = self->textfont()); return ret;
+    LOCK(auto ret = self->textfont());
+    return ret;
 }
 
 void Fl_Value_Slider_set_text_size(Fl_Value_Slider *self, int s) {
@@ -177,7 +182,8 @@ void Fl_Value_Slider_set_text_size(Fl_Value_Slider *self, int s) {
 }
 
 int Fl_Value_Slider_text_size(Fl_Value_Slider *self) {
-    LOCK(auto ret = self->textsize()); return ret;
+    LOCK(auto ret = self->textsize());
+    return ret;
 }
 
 VALUATOR_DEFINE(Fl_Value_Slider)
@@ -197,7 +203,8 @@ void Fl_Value_Input_set_text_color(Fl_Value_Input *self, unsigned int c) {
 }
 
 unsigned int Fl_Value_Input_text_color(Fl_Value_Input *self) {
-    LOCK(auto ret = self->textcolor()); return ret;
+    LOCK(auto ret = self->textcolor());
+    return ret;
 }
 
 void Fl_Value_Input_set_text_font(Fl_Value_Input *self, int f) {
@@ -205,7 +212,8 @@ void Fl_Value_Input_set_text_font(Fl_Value_Input *self, int f) {
 }
 
 int Fl_Value_Input_text_font(Fl_Value_Input *self) {
-    LOCK(auto ret = self->textfont()); return ret;
+    LOCK(auto ret = self->textfont());
+    return ret;
 }
 
 void Fl_Value_Input_set_text_size(Fl_Value_Input *self, int s) {
@@ -213,7 +221,8 @@ void Fl_Value_Input_set_text_size(Fl_Value_Input *self, int s) {
 }
 
 int Fl_Value_Input_text_size(Fl_Value_Input *self) {
-    LOCK(auto ret = self->textsize()); return ret;
+    LOCK(auto ret = self->textsize());
+    return ret;
 }
 
 void Fl_Value_Input_set_soft(Fl_Value_Input *self, char val) {
@@ -221,7 +230,8 @@ void Fl_Value_Input_set_soft(Fl_Value_Input *self, char val) {
 }
 
 char Fl_Value_Input_soft(const Fl_Value_Input *self) {
-    LOCK(auto ret = self->soft()); return ret;
+    LOCK(auto ret = self->soft());
+    return ret;
 }
 
 VALUATOR_DEFINE(Fl_Value_Input)
@@ -235,7 +245,8 @@ void Fl_Value_Output_set_text_color(Fl_Value_Output *self, unsigned int c) {
 }
 
 unsigned int Fl_Value_Output_text_color(Fl_Value_Output *self) {
-    LOCK(auto ret = self->textcolor()); return ret;
+    LOCK(auto ret = self->textcolor());
+    return ret;
 }
 
 void Fl_Value_Output_set_text_font(Fl_Value_Output *self, int f) {
@@ -243,7 +254,8 @@ void Fl_Value_Output_set_text_font(Fl_Value_Output *self, int f) {
 }
 
 int Fl_Value_Output_text_font(Fl_Value_Output *self) {
-    LOCK(auto ret = self->textfont()); return ret;
+    LOCK(auto ret = self->textfont());
+    return ret;
 }
 
 void Fl_Value_Output_set_text_size(Fl_Value_Output *self, int s) {
@@ -251,7 +263,8 @@ void Fl_Value_Output_set_text_size(Fl_Value_Output *self, int s) {
 }
 
 int Fl_Value_Output_text_size(Fl_Value_Output *self) {
-    LOCK(auto ret = self->textsize()); return ret;
+    LOCK(auto ret = self->textsize());
+    return ret;
 }
 
 VALUATOR_DEFINE(Fl_Value_Output)
@@ -295,7 +308,8 @@ void Fl_Hor_Value_Slider_set_text_color(Fl_Hor_Value_Slider *self, unsigned int
 }
 
 unsigned int Fl_Hor_Value_Slider_text_color(Fl_Hor_Value_Slider *self) {
-    LOCK(auto ret = self->textcolor()); return ret;
+    LOCK(auto ret = self->textcolor());
+    return ret;
 }
 
 void Fl_Hor_Value_Slider_set_text_font(Fl_Hor_Value_Slider *self, int f) {
@@ -303,7 +317,8 @@ void Fl_Hor_Value_Slider_set_text_font(Fl_Hor_Value_Slider *self, int f) {
 }
 
 int Fl_Hor_Value_Slider_text_font(Fl_Hor_Value_Slider *self) {
-    LOCK(auto ret = self->textfont()); return ret;
+    LOCK(auto ret = self->textfont());
+    return ret;
 }
 
 void Fl_Hor_Value_Slider_set_text_size(Fl_Hor_Value_Slider *self, int s) {
@@ -311,7 +326,8 @@ void Fl_Hor_Value_Slider_set_text_size(Fl_Hor_Value_Slider *self, int s) {
 }
 
 int Fl_Hor_Value_Slider_text_size(Fl_Hor_Value_Slider *self) {
-    LOCK(auto ret = self->textsize()); return ret;
+    LOCK(auto ret = self->textsize());
+    return ret;
 }
 
 VALUATOR_DEFINE(Fl_Hor_Value_Slider)
